@@ -26,6 +26,7 @@ OC.L10N.register(
     "You will receive a link with the confirmation email" : "Vas recibir un enllaz col mensaxe de confirmación",
     "Where:" : "Ónde:",
     "Comment:" : "Comentariu:",
+    "Location:" : "Llugar:",
     "Previous day" : "Día anterior",
     "Previous week" : "Selmana pasada",
     "Previous year" : "Añu pasáu",
@@ -113,6 +114,7 @@ OC.L10N.register(
     "Calendar name …" : "Nome del calendariu…",
     "Share calendar" : "Compartir el calendariu",
     "Save" : "Guardar",
+    "View" : "Ver",
     "Import calendars" : "Importar calendarios",
     "Please select a calendar to import into …" : "Seleiciona un calendariu al qu'importar …",
     "Filename" : "Nome del ficheru",
@@ -142,17 +144,16 @@ OC.L10N.register(
     "Failed to save default calendar" : "Nun se pue guardar el calendariu predetermináu",
     "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
     "CalDAV link could not be copied to clipboard." : "L'enllaz CalDAV nun se pudo copiar nel cartafueyu.",
+    "General" : "Xeneral",
+    "Personal availability settings" : "Configuración de la disponibilidá personal",
+    "Copy primary CalDAV address" : "Copiar la direición CalDAV primaria",
+    "Copy iOS/macOS CalDAV address" : "Copiar la direición CalDAV d'iOS/macOS",
     "Enable birthday calendar" : "Activar el calendariu de los cumpleaños",
     "Show tasks in calendar" : "Amosar les xeres nel calendariu",
-    "Enable simplified editor" : "Activar l'editor simplificáu",
-    "Limit the number of events displayed in the monthly view" : "Llendar el númberu d'eventos amosaos na vista de meses",
     "Show weekends" : "Amosar les fines de selmana",
     "Show week numbers" : "Amosar los númberos de selmana",
     "Default reminder" : "Recordatoriu predetermináu",
-    "Copy primary CalDAV address" : "Copiar la direición CalDAV primaria",
-    "Copy iOS/macOS CalDAV address" : "Copiar la direición CalDAV d'iOS/macOS",
-    "Personal availability settings" : "Configuración de la disponibilidá personal",
-    "Show keyboard shortcuts" : "Amosar los atayos del tecáu",
+    "Keyboard shortcuts" : "Atayos del tecláu",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutu","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
@@ -200,13 +201,13 @@ OC.L10N.register(
     "Awaiting response" : "Esperando pola rempuesta",
     "Checking availability" : "Comprobando la disponibilidá",
     "Has not responded to {organizerName}'s invitation yet" : "Nun respondió a la invitación de: {organizerName}",
-    "Busy" : "Ocupáu",
-    "Out of office" : "Fuera de la oficina",
-    "with" : "con",
-    "Available times:" : "Hores disponibles:",
     "Suggestion accepted" : "Suxerencia aceptada",
+    "Legend" : "Lleenda",
+    "Out of office" : "Fuera de la oficina",
+    "Attendees:" : "Asistentes:",
     "Done" : "Fecho",
     "Room name" : "Nome de la sala",
+    "Busy" : "Ocupáu",
     "Find a time" : "Atopar una hora",
     "The invitation has been accepted successfully." : "La invitación aceptóse correutamente.",
     "Failed to accept the invitation." : "Nun se pue aceptar la invitación",
@@ -228,7 +229,6 @@ OC.L10N.register(
     "Event title" : "Títulu del eventu",
     "From" : "De",
     "To" : "Pa",
-    "All day" : "Tol día",
     "Repeat" : "Repitir",
     "never" : "enxamás",
     "first" : "primer",
@@ -236,13 +236,16 @@ OC.L10N.register(
     "_week_::_weeks_" : ["selmana","selmanes"],
     "_month_::_months_" : ["mes","meses"],
     "_year_::_years_" : ["añu","años"],
-    "Suggestions" : "Suxerencies",
+    "Resources" : "Recursos",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asientu","{seatingCapacity} asientos"],
     "Has a projector" : "Tien proyeutor",
     "Has a whiteboard" : "Tien pizarra",
     "Projector" : "Proyeutor",
     "Whiteboard" : "Pizarra",
     "More details" : "Mas detalles",
+    "Yes" : "Sí",
+    "No" : "Non",
+    "Create" : "Crear",
     "Please enter a valid date" : "Introduz una data válida",
     "Pick a date" : "Escueyi una data",
     "Global" : "Global",
@@ -251,12 +254,15 @@ OC.L10N.register(
     "Subscribe" : "Soscribise",
     "Time:" : "Hora:",
     "Personal" : "Personal",
+    "Edit event" : "Editar eventu",
     "Event does not exist" : "L'eventu nun esiste",
-    "Details" : "Detalles",
+    "All day" : "Tol día",
     "Invite" : "Convidar",
-    "Resources" : "Recursos",
     "Untitled event" : "Eventu ensin títulu",
     "Close" : "Zarrar",
+    "Title" : "Títulu",
+    "Participants" : "Participantes",
+    "Submit" : "Unviar",
     "Miscellaneous" : "Miscelanea",
     "Daily" : "Caldía",
     "Weekly" : "Selmanalmente",
@@ -288,6 +294,9 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "Prodúxose un error, nun ye posible desaniciar el calendariu",
     "Imported {filename}" : "Importóse «{filename}»",
     "This is an event reminder." : "Esto ye un recordatoriu del eventu.",
-    "User not found" : "Nun s'atopó l'usuariu"
+    "User not found" : "Nun s'atopó l'usuariu",
+    "Enable simplified editor" : "Activar l'editor simplificáu",
+    "Limit the number of events displayed in the monthly view" : "Llendar el númberu d'eventos amosaos na vista de meses",
+    "Show keyboard shortcuts" : "Amosar los atayos del tecáu"
 },
 "nplurals=2; plural=(n != 1);");
