@@ -63,7 +63,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Aftalelinket kunne ikke kopieres til udklipsholderen",
     "Preview" : "Forhåndsvisning",
     "Copy link" : "Kopier link",
-    "Edit" : "Rediger",
+    "Edit" : "Redigér",
     "Delete" : "Slet",
     "Appointment schedules" : "Aftaleplanlægninger",
     "Create new" : "Opret ny",
@@ -74,8 +74,8 @@ OC.L10N.register(
     "An error occurred, unable to change visibility of the calendar." : "Kalenderens synlighed kunne ikke ændres.",
     "Untitled calendar" : "Unanvngiven kalender",
     "Shared with you by" : "Delt med dig af",
-    "Edit and share calendar" : "Rediger og del kalender",
-    "Edit calendar" : "Rediger kalender",
+    "Edit and share calendar" : "Redigér og del kalender",
+    "Edit calendar" : "Redigér kalender",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling af kalenderen om {countdown} sekund","Fjerner deling af kalenderen om {countdown} sekunder"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalenderen bliver slettet om {countdown} sekunder","Kalenderen bliver slettet om {countdown} sekunder"],
     "An error occurred, unable to create the calendar." : "Der opstod en fejl, og kalenderen kunne ikke oprettes.",
@@ -166,7 +166,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n begivenhed blev importeret","%n begivenheder blev importeret"],
     "Import partially failed. Imported {accepted} out of {total}." : "Importen mislykkedes delvist. Importeret {accepted} ud af {total}.",
     "Automatic" : "Automatisk",
-    "Automatic ({detected})" : "Automatisk ({detected})",
+    "Automatic ({timezone})" : "Automatisk ({timezone})",
     "New setting was not saved successfully." : "Den nye indstilling blev ikke gemt.",
     "Timezone" : "Tidszone",
     "Navigation" : "Navigation",
@@ -219,8 +219,8 @@ OC.L10N.register(
     "Private – only accessible via secret link" : "Privat – kun tilgængelig via hemmeligt link",
     "Appointment schedule saved" : "Aftaleplanlægningen gemt",
     "Create appointment schedule" : "Opret aftaleplanlægning",
-    "Edit appointment schedule" : "Rediger aftaleplanlægning",
-    "Update" : "Opdater",
+    "Edit appointment schedule" : "Redigér aftaleplanlægning",
+    "Update" : "Opdatér",
     "Appointment name" : "Aftale navn",
     "Location" : "Sted",
     "Create a Talk room" : "Opret et Snak rum",
@@ -279,7 +279,7 @@ OC.L10N.register(
     "Other notification" : "Anden meddelelse",
     "Relative to event" : "I forhold til begivenhed",
     "On date" : "På dato",
-    "Edit time" : "Rediger tid",
+    "Edit time" : "Redigér tid",
     "Save time" : "Gem tid",
     "Remove reminder" : "Fjern påmindelse",
     "Add reminder" : "Tilføj påmindelse",
@@ -413,8 +413,8 @@ OC.L10N.register(
     "Any" : "Enhver",
     "Minimum seating capacity" : "Minimum siddekapacitet",
     "More details" : "Flere detaljer",
-    "Update this and all future" : "Opdater denne og alle fremtidige",
-    "Update this occurrence" : "Opdater denne forekomst",
+    "Update this and all future" : "Opdatér denne og alle fremtidige",
+    "Update this occurrence" : "Opdatér denne forekomst",
     "Public calendar does not exist" : "Offentlig kalender findes ikke",
     "Maybe the share was deleted or has expired?" : "Måske er delingen blevet slettet eller er udløbet?",
     "Yes" : "Ja",
@@ -586,6 +586,7 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Fejl under parsing af en PROPFIND-fejl",
     "Appointment not found" : "Aftale ikke fundet",
     "User not found" : "Bruger ikke fundet",
+    "Automatic ({detected})" : "Automatisk ({detected})",
     "Shortcut overview" : "Genvejsoversigt",
     "Enable simplified editor" : "Slå simpel editor til",
     "Limit the number of events displayed in the monthly view" : "Begræns antallet af hændelser, der vises i månedsvisningen",
