@@ -39,6 +39,7 @@ OC.L10N.register(
     "Comment:" : "Comentario:",
     "You have a new appointment booking \"%s\" from %s" : "Tienes una nueva reserva de cita \"%s\" de %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Estimado/a %s, %s (%s) ha reservado una cita contigo.",
+    "Location:" : "Ubicación:",
     "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
     "Previous day" : "Día anterior",
     "Previous week" : "Semana anterior",
@@ -140,6 +141,7 @@ OC.L10N.register(
     "Share calendar" : "Compartir calendario",
     "Unshare from me" : "Dejar de compartir conmigo",
     "Save" : "Guardar",
+    "No title" : "Sin título",
     "View" : "Ver",
     "Import calendars" : "Importar calendarios",
     "Please select a calendar to import into …" : "Selecciona un calendario para importar en …",
@@ -157,8 +159,9 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se importó correctamente %n evento","Se importaron correctamente %n eventos","Se importaron correctamente %n eventos"],
     "Import partially failed. Imported {accepted} out of {total}." : "La importación falló parcialmente. Se importaron {accepted} de {total}.",
     "Automatic" : "Automático",
-    "Automatic ({detected})" : "Automático ({detected})",
+    "Automatic ({timezone})" : "({timezone}) automática",
     "New setting was not saved successfully." : "No se guardó correctamente la nueva configuración.",
+    "Timezone" : "Zona horaria",
     "Navigation" : "Navegación",
     "Previous period" : "Periodo anterior",
     "Next period" : "Periodo siguiente",
@@ -176,24 +179,22 @@ OC.L10N.register(
     "Save edited event" : "Guardar evento editado",
     "Delete edited event" : "Eliminar evento editado",
     "Duplicate event" : "Duplicar evento",
-    "Shortcut overview" : "Resumen de accesos directos",
     "or" : "o",
     "Calendar settings" : "Configuración del calendario",
     "No reminder" : "Sin recordatorio",
     "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
     "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
-    "Enable birthday calendar" : "Habilitar calendario de cumpleaños",
-    "Show tasks in calendar" : "Mostrar tareas en el calendario",
-    "Enable simplified editor" : "Habilitar editor simplificado",
-    "Limit the number of events displayed in the monthly view" : "Limitar la cantidad de eventos mostrados en la vista mensual",
-    "Show weekends" : "Mostrar fines de semana",
-    "Show week numbers" : "Mostrar número de semana",
-    "Time increments" : "Incrementos de tiempo",
-    "Default reminder" : "Recordatorio predeterminado",
+    "General" : "General",
+    "Personal availability settings" : "Configuración de disponibilidad personal",
     "Copy primary CalDAV address" : "Copiar dirección CalDAV principal",
     "Copy iOS/macOS CalDAV address" : "Copiar dirección CalDAV para iOS/macOS",
-    "Personal availability settings" : "Configuración de disponibilidad personal",
-    "Show keyboard shortcuts" : "Mostrar accesos directos de teclado",
+    "Enable birthday calendar" : "Habilitar calendario de cumpleaños",
+    "Show tasks in calendar" : "Mostrar tareas en el calendario",
+    "Show weekends" : "Mostrar fines de semana",
+    "Show week numbers" : "Mostrar número de semana",
+    "Editing" : "Edición",
+    "Default reminder" : "Recordatorio predeterminado",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
@@ -356,6 +357,7 @@ OC.L10N.register(
     "Public calendar does not exist" : "El calendario público no existe",
     "Maybe the share was deleted or has expired?" : "¿Tal vez la compartición fue eliminada o ha expirado?",
     "Maybe" : "Tal vez",
+    "Create" : "Crear",
     "from {formattedDate}" : "desde {formattedDate}",
     "to {formattedDate}" : "hasta {formattedDate}",
     "on {formattedDate}" : "el {formattedDate}",
@@ -405,7 +407,10 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["El adjunto requiere acceso compartido","Los adjuntos requieren acceso compartido","Los adjuntos requieren acceso compartido"],
     "Untitled event" : "Evento sin título",
     "Close" : "Cerrar",
+    "Title" : "Título",
+    "30 min" : "30 minutos",
     "Participants" : "Participantes",
+    "Submit" : "Enviar",
     "Subscribe to {name}" : "Suscribirse a {name}",
     "Export {name}" : "Exportar {name}",
     "Anniversary" : "Aniversario",
@@ -495,6 +500,12 @@ OC.L10N.register(
     "Imported {filename}" : "Importado {filename}",
     "This is an event reminder." : "Esto es un recordatorio de evento.",
     "Appointment not found" : "Cita no encontrada",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Automatic ({detected})" : "Automático ({detected})",
+    "Shortcut overview" : "Resumen de accesos directos",
+    "Enable simplified editor" : "Habilitar editor simplificado",
+    "Limit the number of events displayed in the monthly view" : "Limitar la cantidad de eventos mostrados en la vista mensual",
+    "Time increments" : "Incrementos de tiempo",
+    "Show keyboard shortcuts" : "Mostrar accesos directos de teclado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
