@@ -158,7 +158,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
     "Import partially failed. Imported {accepted} out of {total}." : "وارد کردن تا حدودی انجام نشد. وارد شده {accepted} بیرون از {total}.",
     "Automatic" : "خودکار",
-    "Automatic ({detected})" : "خودکار ({شناسایی})",
+    "Automatic ({timezone})" : "خودکار ({شناسایی})",
     "New setting was not saved successfully." : "تنظیم جدید با موفقیت ذخیره نشد.",
     "Navigation" : "جهت یابی",
     "Previous period" : "دوره قبلی",
@@ -177,24 +177,22 @@ OC.L10N.register(
     "Save edited event" : "رویداد ویرایش شده را ذخیره کنید",
     "Delete edited event" : "حذف رویداد ویرایش شده",
     "Duplicate event" : "رویداد تکراری",
-    "Shortcut overview" : "Shortcut overview",
     "or" : "یا",
     "Calendar settings" : "تنظیمات تقویم",
     "No reminder" : "No reminder",
     "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
     "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
-    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
-    "Show tasks in calendar" : "نمایش وظایف در تقویم",
-    "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
-    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
-    "Show weekends" : "آخر هفته ها را نشان دهید",
-    "Show week numbers" : "نمایش شماره های هفته",
-    "Time increments" : "Time increments",
-    "Default reminder" : "Default reminder",
+    "General" : "عمومی",
+    "Personal availability settings" : "Personal availability settings",
     "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
     "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
-    "Personal availability settings" : "Personal availability settings",
-    "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "Enable birthday calendar" : "تقویم تولد را فعال کنید",
+    "Show tasks in calendar" : "نمایش وظایف در تقویم",
+    "Show weekends" : "آخر هفته ها را نشان دهید",
+    "Show week numbers" : "نمایش شماره های هفته",
+    "Editing" : "ویرایش کردن",
+    "Default reminder" : "Default reminder",
+    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
     "0 minutes" : "0 minutes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
@@ -361,7 +359,10 @@ OC.L10N.register(
     "Update this occurrence" : "این رویداد را به روز کنید",
     "Public calendar does not exist" : "تقویم عمومی وجود ندارد",
     "Maybe the share was deleted or has expired?" : "شاید اشتراک حذف شده باشد یا منقضی شده باشد؟",
+    "Yes" : "بله",
+    "No" : "خیر",
     "Maybe" : "Maybe",
+    "Create" : "ایجاد",
     "from {formattedDate}" : "از {formattedDate}",
     "to {formattedDate}" : "به {formattedDate}",
     "on {formattedDate}" : "در {formattedDate}",
@@ -411,7 +412,10 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
     "Untitled event" : "رویداد بدون عنوان",
     "Close" : "بستن",
+    "Title" : "Title",
+    "30 min" : "30 min",
     "Participants" : "شركت كنندگان",
+    "Submit" : "ارسال",
     "Subscribe to {name}" : "اشتراک در {name}",
     "Export {name}" : "دریافت خروجی از {name}",
     "Anniversary" : "سالگرد",
@@ -440,7 +444,7 @@ OC.L10N.register(
     "{time} after the event ends" : "{زمان} پس از پایان این رویداد",
     "on {time}" : "به {موقع}",
     "on {time} ({timezoneId})" : "در {time} ({timezoneId})",
-    "Week {number} of {year}" : "هفته {number} از {year}",
+    "Week {number} of {year}" : "هفتهٔ {number} از {year}",
     "Daily" : "روزانه",
     "Weekly" : "هفته گی",
     "Monthly" : "ماهانه",
@@ -501,6 +505,12 @@ OC.L10N.register(
     "Imported {filename}" : "وارد شده {نام پرونده}",
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
-    "User not found" : "کاربر یافت نشد"
+    "User not found" : "کاربر یافت نشد",
+    "Automatic ({detected})" : "خودکار ({شناسایی})",
+    "Shortcut overview" : "Shortcut overview",
+    "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
+    "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
+    "Time increments" : "Time increments",
+    "Show keyboard shortcuts" : "Show keyboard shortcuts"
 },
 "nplurals=2; plural=(n > 1);");
