@@ -28,7 +28,9 @@ OC.L10N.register(
     "Cancel" : "Cancellar",
     "Automatic" : "Automatic",
     "Actions" : "Actiones",
+    "General" : "General",
     "Show week numbers" : "Monstrar le numero del septimanas",
+    "Keyboard shortcuts" : "Combinationes de claves",
     "Update" : "Actualisar",
     "Location" : "Loco",
     "Description" : "Description",
