@@ -160,8 +160,9 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n개의 일정을 성공적으로 가져옴"],
     "Import partially failed. Imported {accepted} out of {total}." : "가져오기가 부분적으로 실패했습니다. {total} 중 {accepted} 가져옴.",
     "Automatic" : "자동",
-    "Automatic ({detected})" : "자동 ({detected})",
+    "Automatic ({timezone})" : "자동({timezone})",
     "New setting was not saved successfully." : "새로운 설정이 저장되지 않았습니다.",
+    "Timezone" : "시간대",
     "Navigation" : "탐색",
     "Previous period" : "이전 기간",
     "Next period" : "다음 기간",
@@ -179,24 +180,22 @@ OC.L10N.register(
     "Save edited event" : "수정된 일정 저장",
     "Delete edited event" : "수정된 일정 삭제",
     "Duplicate event" : "일정 복제",
-    "Shortcut overview" : "바로가기 개요",
     "or" : "또는",
     "Calendar settings" : "달력 설정",
     "No reminder" : "알림 없음",
     "CalDAV link copied to clipboard." : "CalDAV 링크를 클립보드에 복사했습니다.",
     "CalDAV link could not be copied to clipboard." : "CalDAV 링크를 클립보드에 복사할 수 없습니다.",
-    "Enable birthday calendar" : "생일 달력 활성화",
-    "Show tasks in calendar" : "달력에 작업 보이기",
-    "Enable simplified editor" : "간편한 편집기 활성화",
-    "Limit the number of events displayed in the monthly view" : "월간 보기에서 표시되는 일정의 수 제한",
-    "Show weekends" : "공휴일 보기",
-    "Show week numbers" : "주 번호 보이기",
-    "Time increments" : "시간 단위",
-    "Default reminder" : "기본 알림",
+    "General" : "일반",
+    "Personal availability settings" : "개인별 시간 조율 설정",
     "Copy primary CalDAV address" : "주 CalDAV 주소 복사하기",
     "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV 주소 복사하기",
-    "Personal availability settings" : "개인별 시간 조율 설정",
-    "Show keyboard shortcuts" : "키보드 단축키 표시",
+    "Enable birthday calendar" : "생일 달력 활성화",
+    "Show tasks in calendar" : "달력에 작업 보이기",
+    "Show weekends" : "공휴일 보기",
+    "Show week numbers" : "주 번호 보이기",
+    "Editing" : "글 수정",
+    "Default reminder" : "기본 알림",
+    "Keyboard shortcuts" : "키보드 단축키",
     "Appointment schedule successfully created" : "약속 일정이 성공적으로 생성되었습니다",
     "Appointment schedule successfully updated" : "약속 일정이 성공적으로 갱신되었습니다",
     "_{duration} minute_::_{duration} minutes_" : ["{duration}분"],
@@ -369,6 +368,8 @@ OC.L10N.register(
     "Update this occurrence" : "이 일정 업데이트",
     "Public calendar does not exist" : "공용 달력이 존재하지 않음",
     "Maybe the share was deleted or has expired?" : "공유가 삭제되었거나 만료되었을 수 있습니다.",
+    "Yes" : "예",
+    "No" : "아니오",
     "Maybe" : "아마도",
     "Create" : "생성",
     "from {formattedDate}" : "{formattedDate} 부터",
@@ -423,7 +424,10 @@ OC.L10N.register(
     "_User requires access to your file_::_Users require access to your file_" : ["사용자가 내 파일에 대한 접근을 요구합니다"],
     "Untitled event" : "제목없는 일정",
     "Close" : "닫기",
+    "Title" : "제목",
+    "30 min" : "30분",
     "Participants" : "참가자",
+    "Submit" : "제출",
     "Subscribe to {name}" : "{name} 구독",
     "Export {name}" : "{name} 내보내기",
     "Anniversary" : "기념일",
@@ -511,6 +515,12 @@ OC.L10N.register(
     "Imported {filename}" : "{filename} 가져옴",
     "This is an event reminder." : "일정에 대한 알림입니다.",
     "Appointment not found" : "약속을 찾을 수 없음",
-    "User not found" : "사용자를 찾을 수 없음"
+    "User not found" : "사용자를 찾을 수 없음",
+    "Automatic ({detected})" : "자동 ({detected})",
+    "Shortcut overview" : "바로가기 개요",
+    "Enable simplified editor" : "간편한 편집기 활성화",
+    "Limit the number of events displayed in the monthly view" : "월간 보기에서 표시되는 일정의 수 제한",
+    "Time increments" : "시간 단위",
+    "Show keyboard shortcuts" : "키보드 단축키 표시"
 },
 "nplurals=1; plural=0;");
