@@ -10,6 +10,7 @@ OC.L10N.register(
     "Cheers!" : "ไชโย!",
     "Calendar" : "ปฏิทิน",
     "Confirm" : "ยืนยัน",
+    "Location:" : "ตำแหน่ง:",
     "Previous year" : "ปีที่แล้ว",
     "Next year" : "ปีหน้า",
     "Today" : "วันนี้",
@@ -35,12 +36,16 @@ OC.L10N.register(
     "can edit" : "สามารถแก้ไข",
     "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
     "Save" : "บันทึก",
+    "View" : "มุมมอง",
     "Filename" : "ชื่อไฟล์",
     "Cancel" : "ยกเลิก",
     "Automatic" : "อัตโนมัติ",
     "Year view" : "มุมมองรายปี",
     "List view" : "มุมมองแบบรายการ",
     "Actions" : "การกระทำ",
+    "General" : "ทั่วไป",
+    "Editing" : "กำลังแก้ไข",
+    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "_{duration} year_::_{duration} years_" : ["{duration}ปี"],
     "Update" : "อัปเดต",
     "Location" : "ตำแหน่ง",
@@ -73,13 +78,18 @@ OC.L10N.register(
     "Repeat" : "ทำซ้ำ",
     "never" : "ไม่ต้องเลย",
     "after" : "หลังจาก",
+    "Resources" : "ทรัพยากร",
+    "Yes" : "ใช่",
+    "No" : "ไม่ตกลง",
+    "Create" : "สร้าง",
     "Pick a date" : "เลือกวันที่",
     "Global" : "ทั่วไป",
     "Subscribe" : "สมัครรับข้อมูล",
     "Personal" : "ส่วนตัว",
-    "Details" : "รายละเอียด",
-    "Resources" : "ทรัพยากร",
+    "Edit event" : "แก้ไขกิจกรรม",
     "Close" : "ปิด",
+    "Selected" : "เลือกอยู่",
+    "Submit" : "ส่ง",
     "Anniversary" : "วันครบรอบ",
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
     "Daily" : "รายวัน",
